==> adapters-2023.04.27-698.jar: com/vadelabs/adapter_postgres/spec.clj <==
(ns com.vadelabs.adapter-postgres.spec
  #_(:require
     [com.vadelabs.utils-core.interface :as uc]))

;; (def remote-type
;;   "Mapping from local types to SQL type names"
;;   {:attribute.type/bigdec :double-precision
;;    :attribute.type/bigint :bigint
;;    :attribute.type/boolean :boolean
;;    :attribute.type/double :double-precision
;;    :attribute.type/float :double-precision
;;    :attribute.type/instant :timestamp-without-time-zone
;;    :attribute.type/keyword :text
;;    :attribute.type/long :bigint
;;    :attribute.type/map :jsonb
;;    :attribute.type/string :text
;;    :attribute.type/symbol :text
;;    :attribute.type/tuple :jsonb
;;    :attribute.type/uuid :uuid
;;    :attribute.type/uri :text
;;    :attribute.type/enum :enum})

;; (defn ^:private schema
;;   [{:attribute/keys [remote-ns]}]
;;   [remote-ns {:name remote-ns}])

;; (defn ^:private schemas
;;   [attributes]
;;   (->> attributes
;;     (map schema)
;;     (into {})))

;; (defn ^:private columns
;;   [attributes]
;;   (->> attributes
;;     (reduce
;;       (fn [acc {:attribute/keys [remote-ns remote-entity remote-key remote-type optional default]}]
;;         (assoc acc remote-key
;;           {:name remote-key
;;            :type remote-type
;;            :props (cond-> {:not-null (not optional)
;;                            :schema remote-ns
;;                            :table remote-entity}
;;                     default (assoc :default default))}))
;;       {})))

;; (defn ^:private primary-key
;;   [remote-entity attributes]
;;   {:name (->> [remote-entity :pkey]
;;            (map uc/namify)
;;            (uc/str-join "_")
;;            uc/keywordize)
;;    :fields (->> attributes
;;              (filter :attribute/primary-key)
;;              (mapv :attribute/remote-key))})

;; (defn ^:private table
;;   [remote-ns remote-entity attributes]
;;   {:name (->> [remote-ns remote-entity]
;;            (map uc/namify)
;;            (uc/str-join ".")
;;            uc/keywordize)
;;    :columns (columns attributes)
;;    :primary-key (primary-key remote-entity attributes)})

;; (defn ^:private tables
;;   [attributes]
;;   (->> attributes
;;     (uc/group-by (juxt :attribute/remote-ns
;;                    :attribute/remote-entity))
;;     (reduce-kv
;;       (fn [acc [remote-ns remote-entity] attributes]
;;         (assoc acc remote-entity (table remote-ns remote-entity attributes)))
;;       {})))

;; (defn ^:private enums
;;   [attributes]
;;   (->> attributes
;;     (uc/group-by :attribute/remote-type)
;;     :enum
;;     (reduce
;;       (fn [acc {:attribute/keys [remote-ns remote-entity remote-key remote-type options]}]
;;         (let [type-name (->> [remote-entity remote-key remote-type]
;;                           (map uc/namify)
;;                           (uc/str-join "_")
;;                           (uc/prefix-keyword "." remote-ns))]
;;           (assoc acc type-name {:name type-name :options options})))
;;       {})))

;; (defn model
;;   [attributes]
;;   {:schemas (schemas attributes)
;;    :tables (tables attributes)
;;    :enums (enums attributes)})

==> adapters-2023.05.11-746.jar: com/vadelabs/adapter_postgres/spec.clj <==
(ns com.vadelabs.adapter-postgres.spec
  #_(:require
     [com.vadelabs.utils-core.interface :as uc]))

;; (def remote-type
;;   "Mapping from local types to SQL type names"
;;   {:attribute.type/bigdec :double-precision
;;    :attribute.type/bigint :bigint
;;    :attribute.type/boolean :boolean
;;    :attribute.type/double :double-precision
;;    :attribute.type/float :double-precision
;;    :attribute.type/datetime :timestamp-without-time-zone
;;    :attribute.type/keyword :text
;;    :attribute.type/long :bigint
;;    :attribute.type/map :jsonb
;;    :attribute.type/string :text
;;    :attribute.type/symbol :text
;;    :attribute.type/tuple :jsonb
;;    :attribute.type/uuid :uuid
;;    :attribute.type/uri :text
;;    :attribute.type/enum :enum})

;; (defn ^:private schema
;;   [{:attribute/keys [remote-ns]}]
;;   [remote-ns {:name remote-ns}])

;; (defn ^:private schemas
;;   [attributes]
;;   (->> attributes
;;     (map schema)
;;     (into {})))

;; (defn ^:private columns
;;   [attributes]
;;   (->> attributes
;;     (reduce
;;       (fn [acc {:attribute/keys [remote-ns remote-entity remote-key remote-type optional default]}]
;;         (assoc acc remote-key
;;           {:name remote-key
;;            :type remote-type
;;            :props (cond-> {:not-null (not optional)
;;                            :schema remote-ns
;;                            :table remote-entity}
;;                     default (assoc :default default))}))
;;       {})))

;; (defn ^:private primary-key
;;   [remote-entity attributes]
;;   {:name (->> [remote-entity :pkey]
;;            (map uc/namify)
;;            (uc/str-join "_")
;;            uc/keywordize)
;;    :fields (->> attributes
;;              (filter :attribute/primary-key)
;;              (mapv :attribute/remote-key))})

;; (defn ^:private table
;;   [remote-ns remote-entity attributes]
;;   {:name (->> [remote-ns remote-entity]
;;            (map uc/namify)
;;            (uc/str-join ".")
;;            uc/keywordize)
;;    :columns (columns attributes)
;;    :primary-key (primary-key remote-entity attributes)})

;; (defn ^:private tables
;;   [attributes]
;;   (->> attributes
;;     (uc/group-by (juxt :attribute/remote-ns
;;                    :attribute/remote-entity))
;;     (reduce-kv
;;       (fn [acc [remote-ns remote-entity] attributes]
;;         (assoc acc remote-entity (table remote-ns remote-entity attributes)))
;;       {})))

;; (defn ^:private enums
;;   [attributes]
;;   (->> attributes
;;     (uc/group-by :attribute/remote-type)
;;     :enum
;;     (reduce
;;       (fn [acc {:attribute/keys [remote-ns remote-entity remote-key remote-type options]}]
;;         (let [type-name (->> [remote-entity remote-key remote-type]
;;                           (map uc/namify)
;;                           (uc/str-join "_")
;;                           (uc/prefix-keyword "." remote-ns))]
;;           (assoc acc type-name {:name type-name :options options})))
;;       {})))

;; (defn model
;;   [attributes]
;;   {:schemas (schemas attributes)
;;    :tables (tables attributes)
;;    :enums (enums attributes)})
